@@ -6,6 +6,7 @@
 #'
 #' @name deductive
 #' @docType  package
+#' @aliases deductive-package
 #' @import methods
 #' @import lintools
 #' @import validate
@@ -13,6 +14,6 @@
 #' @importFrom stats complete.cases 
 #' @importFrom stats setNames
 #' @useDynLib deductive, .registration=TRUE
-{}
+"_PACKAGE"
 
 
